/*
FacebookAlbumDemo - Example of how to display Facebook albums in an Android application
Copyright (C) 2010-2011 Hugues Johnson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
 */

package com.huguesjohnson.facebookalbumdemo;

import java.util.ArrayList;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;

public class AlbumImageAdapter extends BaseAdapter{
	private final static String TAG="AlbumImageAdapter";
	private ArrayList<PhotoItem> photos;
	private Context context;
	private int albumGalleryItemBackground;
	
	public AlbumImageAdapter(Context context,ArrayList<PhotoItem> photos){
		this.context=context;
		this.photos=photos;
        TypedArray ta=context.obtainStyledAttributes(R.styleable.AlbumGallery);
        albumGalleryItemBackground=ta.getResourceId(R.styleable.AlbumGallery_android_galleryItemBackground,0);
        ta.recycle();
	}
	
	@Override
	public int getCount(){
		return(this.photos.size());
	}

	@Override
	public Object getItem(int position){
		return(this.photos.get(position));
	}

	@Override
	public long getItemId(int position){
		return(position);
	}

	@Override
	public View getView(int position,View convertView,ViewGroup parent){
        ImageView imageView=new ImageView(context);
        imageView.setScaleType(ImageView.ScaleType.FIT_XY);
        imageView.setBackgroundResource(albumGalleryItemBackground);
        //load the image
        String pictureUrl=this.photos.get(position).getPictureUrl();
        try{
			Bitmap bitmap=ImageCache.get(pictureUrl);
			if(bitmap==null){
				bitmap=HttpFetch.fetchBitmap(pictureUrl);
				ImageCache.put(pictureUrl,bitmap);
			}
			imageView.setImageBitmap(bitmap);
        }catch(Exception x){
        	Log.e(TAG,"getView",x);
        }
        return(imageView);
	}
}
