/*
FacebookAlbumDemo - Example of how to display Facebook albums in an Android application
Copyright (C) 2010-2011 Hugues Johnson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
 */

package com.huguesjohnson.facebookalbumdemo;

import java.io.IOException;
import java.util.ArrayList;

import org.curiouscreature.android.shelves.util.UserTask;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Gallery;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.AdapterView.OnItemSelectedListener;

public class FacebookAlbumDemoActivity extends Activity{
	private final static String TAG="FacebookAlbumDemoActivity";
	private ArrayAdapter<AlbumItem> albumArrayAdapter;
	private AlbumItem selectedAlbum;
	private PhotoItem selectedImage;
	//references to ui controls
	private Spinner spinnerSelectAlbum;
	private TextView textViewAlbumDescription;
	private Gallery gallerySelectedAlbum;
	private ImageView imageViewSelectedImage;

	/*	UserTasks to asynchronously load stuff */
	
	private class UpdateAlbumGalleryTask extends UserTask<String,String,ArrayList<PhotoItem>>{
		public ArrayList<PhotoItem> doInBackground(String... urls){
			try{
				Resources r=getResources();
        		//invoke the API to get posts
        		long startTime=System.currentTimeMillis();
        		String facebookUrlPhotos=(r.getString(R.string.facebook_url_photos)).replace("[ALBUMID]",selectedAlbum.getId());
        		String photosJson=RestInvoke.invoke(facebookUrlPhotos);
        		long endTime=System.currentTimeMillis();
                Log.d(TAG,"Time to download photos="+(endTime-startTime)+"ms");
        		//parse out the latest status
                startTime=endTime;
                ArrayList<PhotoItem> photos=FacebookJSONParser.parsePhotos(photosJson);
        		endTime=System.currentTimeMillis();
                Log.d(TAG,"Time to parse latest status="+(endTime-startTime)+"ms");
				return(photos);
			}catch(Exception x){
				Log.e(TAG,"UpdateAlbumGalleryTask",x);
    	    	return(null);
			}
	     }

	     public void onPostExecute(ArrayList<PhotoItem> photos){
	    	 if((photos==null)||(photos.size()<1)){
	    		 textViewAlbumDescription.setText("Unable to download "+selectedAlbum.getName());
	    	 }else{
	    		 textViewAlbumDescription.setText(selectedAlbum.getDescription());
	    		 gallerySelectedAlbum.setAdapter(new AlbumImageAdapter(getApplicationContext(),photos));
	    	 }
	     }
	 }

	private class DownloadImageTask extends UserTask<String,String,Bitmap>{
		public Bitmap doInBackground(String... params){
			try{
				Log.d(TAG,"DownloadImageTask.doInBackground");
				String imageUrl=selectedImage.getSourceUrl();
				Log.d(TAG,"DownloadImageTask.doInBackground, imageUrl="+imageUrl);
				Bitmap bitmap=ImageCache.get(imageUrl);
				if(bitmap!=null){return(bitmap);}
        		long startTime=System.currentTimeMillis();
				bitmap=HttpFetch.fetchBitmap(imageUrl);
        		long endTime=System.currentTimeMillis();
        		Log.d(TAG,"DownloadEpisodeLogoTask.doInBackground, Time to fetch bitmap="+(endTime-startTime)+"ms");
				ImageCache.put(imageUrl,bitmap);
				return(bitmap);
			}catch(IOException iox){
				Log.e(TAG,"DownloadImageTask",iox);
    	    	return(null);
			}
	     }

	     public void onPostExecute(Bitmap result){
	    	 imageViewSelectedImage.setImageBitmap(result);
	     }
	 }

	private class GetAlbumsTask extends UserTask<String,String,String>{
		public String doInBackground(String... params){
			try{
        		//invoke the API to get albums
				long startTime=System.currentTimeMillis();
        		String albumsJson=RestInvoke.invoke(getResources().getString(R.string.facebook_url_albums));
        		long endTime=System.currentTimeMillis();
                Log.d(TAG,"Time to download albums="+(endTime-startTime)+"ms");
        		//parse the albums
                startTime=endTime;
                ArrayList<AlbumItem> albums=FacebookJSONParser.parseAlbums(albumsJson);
        		endTime=System.currentTimeMillis();
                Log.d(TAG,"Time to parse albums="+(endTime-startTime)+"ms");
        		//update the select album spinner
                if(albums.size()>0){
                	albumArrayAdapter=new ArrayAdapter<AlbumItem>(getApplicationContext(),android.R.layout.simple_spinner_item,albums);
                }
                return("");
			}catch(Exception x){
				Log.e(TAG,"GetAlbumsTask",x);
    	    	return(null);
			}
	     }

	     public void onPostExecute(String result){
	 		if((albumArrayAdapter==null)||(albumArrayAdapter.isEmpty())){
		      	ArrayList<String> defaultList=new ArrayList<String>();
		      	defaultList.add("No albums found");
		      	ArrayAdapter<String> defaultAdapter=new ArrayAdapter<String>(getApplicationContext(),android.R.layout.simple_spinner_item,defaultList);
		      	spinnerSelectAlbum.setAdapter(defaultAdapter);
		      	spinnerSelectAlbum.setEnabled(false);
			}else{
		      	spinnerSelectAlbum.setAdapter(albumArrayAdapter);
		      	spinnerSelectAlbum.setEnabled(true);
			}
	     }
	 }
	
	/*	UI listeners */
	
	public class AlbumSelectedListener implements OnItemSelectedListener{
		public void onItemSelected(AdapterView<?> parent,View view,int pos,long id){
			selectedAlbum=(AlbumItem)spinnerSelectAlbum.getItemAtPosition(pos);
			updateAlbum();
		}

	    public void onNothingSelected(AdapterView<?> parent){/* not implemented */}
	}	
	
	public class OnPhotoClickedListener implements OnItemClickListener{
		@Override
		public void onItemClick(AdapterView<?> parent,View view,int position,long id){
			selectedImage=(PhotoItem)gallerySelectedAlbum.getItemAtPosition(position);
			showImageDialog();
		}
	}
	
	/* onCreate, onResume */
	
    @Override
    public void onCreate(Bundle savedInstanceState){
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        this.spinnerSelectAlbum=(Spinner)this.findViewById(R.id.SpinnerSelectAlbum);
        this.spinnerSelectAlbum.setOnItemSelectedListener(new AlbumSelectedListener());
        this.textViewAlbumDescription=(TextView)this.findViewById(R.id.TextViewAlbumDescription);
        this.gallerySelectedAlbum=(Gallery)this.findViewById(R.id.GallerySelectedAlbum);
        this.gallerySelectedAlbum.setOnItemClickListener(new OnPhotoClickedListener());
    }
    
	@Override
	protected void onResume(){
		super.onResume();
		//check for albums
		if((this.albumArrayAdapter==null)||(this.albumArrayAdapter.getCount()<1)){
			new GetAlbumsTask().execute("");
		}
	}

	/* private methods */
    
	private void updateAlbum(){
		this.gallerySelectedAlbum.setEnabled(false);
		this.textViewAlbumDescription.setText("Loading "+this.selectedAlbum.getName()+"...");
		new UpdateAlbumGalleryTask().execute("");
	}
	
	private void showImageDialog(){
		try{
			//create the dialog
			LayoutInflater inflater=(LayoutInflater)this.getSystemService(LAYOUT_INFLATER_SERVICE);
			View layout=inflater.inflate(R.layout.viewimagelayout,(ViewGroup)findViewById(R.id.ViewImageDialogRoot));
			AlertDialog.Builder builder=new AlertDialog.Builder(this);
			builder.setView(layout);
			builder.setTitle("View Image");
			builder.setPositiveButton("Close",null);
			AlertDialog imageDialog=builder.create();
			//show the dialog
			imageDialog.show();
			this.imageViewSelectedImage=(ImageView)imageDialog.findViewById(R.id.ImageViewSourceImage);
			//load the image
			new DownloadImageTask().execute("");
		}catch(Exception x){
			Log.e(TAG,"showImageDialog",x);
		}	
	}
}
