/*
FacebookAlbumDemo - Example of how to display Facebook albums in an Android application
Copyright (C) 2010-2011 Hugues Johnson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
 */

package com.huguesjohnson.facebookalbumdemo;

import java.util.ArrayList;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;


public abstract class FacebookJSONParser{

	public static String parseLatestStatus(String json){
		String latestStatus="";
		String startTag="\"message\":\"";
		int indexOf=json.indexOf(startTag);
		if(indexOf>0){
			int start=indexOf+startTag.length();
			String endTag="\",";
			return(json.substring(start,json.indexOf(endTag,start)));
		}
		return(latestStatus);
	}
	
	public static ArrayList<AlbumItem> parseAlbums(String json) throws JSONException{
		ArrayList<AlbumItem> albums=new ArrayList<AlbumItem>();
		JSONObject rootObj=new JSONObject(json);
		JSONArray itemList=rootObj.getJSONArray("data");
		int albumCount=itemList.length();
		for(int albumIndex=0;albumIndex<albumCount;albumIndex++){
			JSONObject album=itemList.getJSONObject(albumIndex);
			String description="";
			try{
				description=album.getString("description");
			}catch(JSONException x){/*not implemented*/}
			albums.add(new AlbumItem(album.getString("id"),album.getString("name"),description));
		}
		return(albums);
	}

	public static ArrayList<PhotoItem> parsePhotos(String json) throws JSONException{
		ArrayList<PhotoItem> photos=new ArrayList<PhotoItem>();
		JSONObject rootObj=new JSONObject(json);
		JSONArray itemList=rootObj.getJSONArray("data");
		int photoCount=itemList.length();
		for(int photoIndex=0;photoIndex<photoCount;photoIndex++){
			JSONObject photo=itemList.getJSONObject(photoIndex);
			photos.add(new PhotoItem(photo.getString("picture"),photo.getString("source")));
		}
		return(photos);
	}
}
